@@ -22,7 +22,7 @@ from subprocess import Popen
 import gtk
 import sys
 from generator import GeneratorTask
-
+import getopt
 
 DATABASE = "/home/user/.mafw.db"
 ERADIOLIST = "eradio.list"
@@ -90,6 +90,7 @@ class GreekInternetRadio(hildon.Program):
        
         # stop media play iradio manager
         Popen(["/usr/bin/mafw.sh", "stop", "mafw-iradio-source"])
+        self.remove_entries(cursor)
         self.insertIntoDB(cursor, self.playlist)
        
         # close the database
@@ -141,15 +142,20 @@ class GreekInternetRadio(hildon.Program):
                 cursor.execute('INSERT INTO iradiobookmarks VALUES (?, "title", ?)', (stationId, self.buildBlob(title),))
                 cursor.execute('INSERT INTO iradiobookmarks VALUES (?, "mime-type", ?)', (stationId, self.buildBlob("audio"),))
                 cursor.execute('INSERT INTO iradiobookmarks VALUES (?, "uri", ?)', (stationId, self.buildBlob(uri),))
-            else:
-                # station is listed. Update the uri entry
-                cursor.execute('UPDATE iradiobookmarks SET value = ? WHERE id = ? AND key = "uri" ', (self.buildBlob(uri), stationId))
-            
+                cursor.execute('INSERT INTO iradiobookmarks VALUES (?, "x-added-by", ?)', (stationId, self.buildBlob("greekiradio")))
+
             i += 2
 
     def create_menu(self,label):
         menu = hildon.AppMenu()
+
+        # remove button
+        button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        button.set_label("Remove stations")
+        button.connect("clicked", self.on_remove_button_clicked)
+        menu.append(button)
         
+
         # about button
         button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
         button.set_label("About")
@@ -170,7 +176,57 @@ class GreekInternetRadio(hildon.Program):
         about.connect("response", lambda x, y: x.destroy())
         about.show()
         
+    def on_remove_button_clicked(self, widget):
+        # connect to the database
+        conn = sqlite3.connect(DATABASE)
+        cursor = conn.cursor()
+        
+        # stop media play iradio manager
+        Popen(["/usr/bin/mafw.sh", "stop", "mafw-iradio-source"])
+        self.remove_entries(cursor)
+
+        # close the database
+        conn.commit()
+        conn.close()
+
+        Popen(["/usr/bin/mafw.sh", "start", "mafw-iradio-source"])        
+        self.display_status("All entries removed.")
+                
+    def remove_entries(self, cursor):
+        cursor.execute('SELECT id FROM iradiobookmarks WHERE key = "x-added-by" AND value = ?', (self.buildBlob("greekiradio"),) )
+        for row in cursor.fetchall():
+            cursor.execute('DELETE FROM iradiobookmarks WHERE id = ?', (row[0],))
+
+        
+                
         
 if __name__ == "__main__":
     app = GreekInternetRadio() 
+    try:
+        opts, args = getopt.getopt(sys.argv[1:], "", ["remove"])
+    except getopt.GetoptError, err:
+        print str(err)
+        sys.exit(2)
+        
+    for o, a in opts:
+        if o == "--remove":
+            # remove db entries
+            # connect to the database
+            conn = sqlite3.connect(DATABASE)
+            cursor = conn.cursor()
+
+            # stop media play iradio manager
+            Popen(["/usr/bin/mafw.sh", "stop", "mafw-iradio-source"])
+            app.remove_entries()
+                               
+            # close the database
+            conn.commit()
+            conn.close()
+            
+            # update media play list
+            Popen(["/usr/bin/mafw.sh", "start", "mafw-iradio-source"])
+ 
+            sys.exit(0)
+
+
     app.run()      
